@@ -9,7 +9,7 @@
 
 #include "fstabstorageaccess.h"
 #include <QPointer>
-#include <QStringList>
+#include <QString>
 #include <solid/devices/ifaces/device.h>
 
 namespace Solid
@@ -25,7 +25,7 @@ class FstabDevice : public Solid::Ifaces::Device
 public:
     FstabDevice(QString uid);
 
-    virtual ~FstabDevice();
+    ~FstabDevice() override;
 
     QString udi() const override;
 
